@@ -20,7 +20,9 @@ pub struct RwOps<'a> {
 
 impl std::fmt::Debug for RwOps<'_> {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
-        f.debug_struct("RwOps").finish()
+        f.debug_struct("RwOps")
+            .field("size", &self.size())
+            .finish_non_exhaustive()
     }
 }
 
