@@ -16,7 +16,7 @@ impl std::fmt::Debug for WindowSurface<'_> {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
         f.debug_struct("WindowSurface")
             .field("window", &self.window)
-            .finish()
+            .finish_non_exhaustive()
     }
 }
 
